"use strict";
exports.__esModule = true;
exports.isAnyJsonSchema = exports.isObjectJsonSchema = exports.isArrayJsonSchema = exports.isIntegerJsonSchema = exports.isNumberJsonSchema = exports.isStringJsonSchema = exports.isBooleanJsonSchema = exports.isNullJsonSchema = exports.isReference = void 0;
function isReference(schema) {
    return typeof schema.$ref === 'string';
}
exports.isReference = isReference;
function isNullJsonSchema(schema) {
    if (schema.type === 'null') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('null')) {
        return true;
    }
    return false;
}
exports.isNullJsonSchema = isNullJsonSchema;
function isBooleanJsonSchema(schema) {
    if (schema.type === 'boolean') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('boolean')) {
        return true;
    }
    return false;
}
exports.isBooleanJsonSchema = isBooleanJsonSchema;
function isStringJsonSchema(schema) {
    if (schema.type === 'string') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('string')) {
        return true;
    }
    if (schema.type === undefined && (schema.pattern !== undefined ||
        schema.minLength !== undefined ||
        schema.maxLength !== undefined)) {
        return true;
    }
    return false;
}
exports.isStringJsonSchema = isStringJsonSchema;
function isNumberJsonSchema(schema) {
    if (schema.type === 'number') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('number')) {
        return true;
    }
    if (schema.type === undefined && (schema.multipleOf !== undefined ||
        schema.minimum !== undefined ||
        schema.maximum !== undefined ||
        schema.exclusiveMinimum !== undefined ||
        schema.exclusiveMaximum !== undefined)) {
        return true;
    }
    return false;
}
exports.isNumberJsonSchema = isNumberJsonSchema;
function isIntegerJsonSchema(schema) {
    if (schema.type === 'integer') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('integer')) {
        return true;
    }
    if (schema.type === undefined && (schema.multipleOf !== undefined ||
        schema.minimum !== undefined ||
        schema.maximum !== undefined ||
        schema.exclusiveMinimum !== undefined ||
        schema.exclusiveMaximum !== undefined)) {
        return true;
    }
    return false;
}
exports.isIntegerJsonSchema = isIntegerJsonSchema;
function isArrayJsonSchema(schema) {
    if (schema.type === 'array') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('array')) {
        return true;
    }
    if (schema.type === undefined && (schema.contains !== undefined ||
        schema.items !== undefined ||
        schema.maxContains !== undefined ||
        schema.maxItems !== undefined ||
        schema.minContains !== undefined ||
        schema.minItems !== undefined ||
        schema.prefixItems !== undefined ||
        schema.uniqueItems !== undefined)) {
        return true;
    }
    return false;
}
exports.isArrayJsonSchema = isArrayJsonSchema;
function isObjectJsonSchema(schema) {
    if (schema.type === 'object') {
        return true;
    }
    if (Array.isArray(schema.type) && schema.type.includes('object')) {
        return true;
    }
    if (schema.type === undefined && (schema.additionalProperties !== undefined ||
        schema.dependentRequired !== undefined ||
        schema.maxProperties !== undefined ||
        schema.minProperties !== undefined ||
        schema.patternProperties !== undefined ||
        schema.properties !== undefined ||
        schema.propertyNames !== undefined ||
        schema.required !== undefined)) {
        return true;
    }
    return false;
}
exports.isObjectJsonSchema = isObjectJsonSchema;
function isAnyJsonSchema(schema) {
    return !isReference(schema)
        && !isNullJsonSchema(schema)
        && !isBooleanJsonSchema(schema)
        && !isStringJsonSchema(schema)
        && !isNumberJsonSchema(schema)
        && !isIntegerJsonSchema(schema)
        && !isArrayJsonSchema(schema)
        && !isObjectJsonSchema(schema);
}
exports.isAnyJsonSchema = isAnyJsonSchema;
//# sourceMappingURL=jsonSchema.js.map